
import 'dart:async';

import 'package:flutter/services.dart';

class OneFlow {
  static const MethodChannel methodchannel =
      const MethodChannel('flutter_1flow_sdk');

 
  static Future<void> configure(String projectKey, [bool enableSurveys = true]) async {
    try {
      Map<String, Object> args = <String, Object>{};
      args.putIfAbsent("projectKey", () => projectKey);
      args.putIfAbsent("enableSurveys", () => enableSurveys);
      await methodchannel.invokeMethod('configure', args);
    }catch(err){
      throw Exception("error occured : ${err.toString()}");
    }
  }

  static Future<void> useFont({String fontFamily = "", String path = ""}) async {
    try {
      Map<String, Object> args = <String, Object>{};
      args.putIfAbsent("fontFamily", () => fontFamily);
      args.putIfAbsent("path", () => path);
      await methodchannel.invokeMethod('useFont', args);
    }catch(err){
      throw Exception("error occured : ${err.toString()}");
    }
  }

  static Future<void> enableSurveys(bool enableSurveys) async {
    try {
      Map<String, Object> args = <String, Object>{};
      args.putIfAbsent("enableSurveys", () => enableSurveys);
      await methodchannel.invokeMethod('enableSurveys', args);
    }catch(err){
      throw Exception("error occured : ${err.toString()}");
    }
  }

  static Future<void> logUser(String uniqueId, [Object? userDetails]) async {
    try {
        Map<String, Object> args = <String, Object>{};
        if (userDetails != null && userDetails.runtimeType == Object) {
          args.putIfAbsent("userDetails", () => userDetails);
        }
        args.putIfAbsent("uniqueId", () => uniqueId);
        await methodchannel.invokeMethod('logUser', args);

    } catch(err){
      throw Exception("error occured : ${err.toString()}");
    }
  }

  static Future<void> recordEventName(String eventName, [Object? parameters]) async {
    try {
      Map<String, Object> args = <String, Object>{};
      if (parameters != null && parameters.runtimeType == Object) {
        args.putIfAbsent("parameters", () => parameters);
      }
      args.putIfAbsent("eventName", () => eventName);
      print("recordEventName ");
      await methodchannel.invokeMethod('recordEventName', args);
    }catch(err){
      throw Exception("error occured : ${err.toString()}");
    }
  }



   static Future<void> startFlow(String flowId) async {
    try {
      Map<String, Object> args = <String, Object>{};
      args.putIfAbsent("flowId", () => flowId);
      print("startFlow ");
      await methodchannel.invokeMethod('startFlow', args);
    }catch(err){
      throw Exception("error occured : ${err.toString()}");
    }
  }

  static Future<String> getSDKVersion() async {
     return "2023.6.20";
  }
}
